# MediaServices

> see https://aka.ms/autorest

This is the AutoRest configuration file for MediaServices.

---

## Getting Started

To build the SDK for MediaServices, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`

---

## Configuration

### Basic Information

These are the global settings for the MediaServices API.

``` yaml
openapi-type: arm
tag: package-preview-1919-09
```


### Tag: package-preview-1919-09

These settings apply only when `--tag=package-preview-1919-09` is specified on the command line.

```yaml $(tag) == 'package-preview-1919-09'
input-file:
  - Microsoft.Media/preview/1919-09-12-preview/Accounts.json
  - Microsoft.Media/preview/1919-09-12-preview/Assets.json
  - Microsoft.Media/preview/1919-09-12-preview/Common.json
  - Microsoft.Media/preview/1919-09-12-preview/ContentKeyPolicies.json
  - Microsoft.Media/preview/1919-09-12-preview/Encoding.json
  - Microsoft.Media/preview/1919-09-12-preview/StreamingPoliciesAndStreamingLocators.json
  - Microsoft.Media/preview/1919-09-12-preview/streamingservice.json
```
### Tag: package-2018-07

These settings apply only when `--tag=package-2018-07` is specified on the command line.

``` yaml $(tag) == 'package-2018-07'
input-file:
  - Microsoft.Media/stable/2018-07-01/AccountFilters.json
  - Microsoft.Media/stable/2018-07-01/Accounts.json
  - Microsoft.Media/stable/2018-07-01/AssetsAndAssetFilters.json
  - Microsoft.Media/stable/2018-07-01/Common.json
  - Microsoft.Media/stable/2018-07-01/ContentKeyPolicies.json
  - Microsoft.Media/stable/2018-07-01/Encoding.json
  - Microsoft.Media/stable/2018-07-01/StreamingPoliciesAndStreamingLocators.json
  - Microsoft.Media/stable/2018-07-01/streamingservice.json
```

### Tag: package-2015-10

These settings apply only when `--tag=package-2015-10` is specified on the command line.

``` yaml $(tag) == 'package-2015-10'
input-file:
- Microsoft.Media/stable/2015-10-01/media.json
```

### Tag: package-2018-03-preview

These settings apply only when `--tag=package-2018-03-preview` is specified on the command line.

``` yaml $(tag) == 'package-2018-03-preview'
input-file:
- Microsoft.Media/preview/2018-03-30-preview/Accounts.json
- Microsoft.Media/preview/2018-03-30-preview/Assets.json
- Microsoft.Media/preview/2018-03-30-preview/ContentKeyPolicies.json
- Microsoft.Media/preview/2018-03-30-preview/Encoding.json
- Microsoft.Media/preview/2018-03-30-preview/StreamingPoliciesAndStreamingLocators.json
- Microsoft.Media/preview/2018-03-30-preview/streamingservice.json
```

### Tag: package-2018-06-preview

These settings apply only when `--tag=package-2018-06-preview` is specified on the command line.

``` yaml $(tag) == 'package-2018-06-preview'
input-file:
- Microsoft.Media/preview/2018-06-01-preview/Accounts.json
- Microsoft.Media/preview/2018-06-01-preview/Assets.json
- Microsoft.Media/preview/2018-06-01-preview/ContentKeyPolicies.json
- Microsoft.Media/preview/2018-06-01-preview/Encoding.json
- Microsoft.Media/preview/2018-06-01-preview/StreamingPoliciesAndStreamingLocators.json
- Microsoft.Media/preview/2018-06-01-preview/streamingservice.json
```

---

# Code Generation

## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-node
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_media_services']
```

## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  # last generated from commit 3586e2989d502434c4f607dd38d40e46aabede5c
  azure-arm: true
  payload-flattening-threshold: 2
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.Media
  output-folder: $(csharp-sdks-folder)/Media/Management.Media/Generated
  clear-output-folder: true
  opt-in-extensible-enums: true 
```

## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.
Use `--python-mode=update` if you already have a setup.py and just want to update the code itself.

``` yaml $(python)
python-mode: create
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: azure.mgmt.media
  package-name: azure-mgmt-media
  clear-output-folder: true
```

``` yaml $(python) && $(python-mode) == 'update'
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/azure-mgmt-media/azure/mgmt/media
```

``` yaml $(python) && $(python-mode) == 'create'
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/azure-mgmt-media
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.mediaservices
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-mediaservices
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2015-10
  - tag: package-2018-03-preview
  - tag: package-2018-06-preview
  - tag: package-2018-07
```

### Tag: package-2015-10 and java

These settings apply only when `--tag=package-2015-10 --java` is specified on the command line.
Please also specify the `--azure-libraries-for-java-folder=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2015-10' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.mediaservices.v2015_10_01
  output-folder: $(azure-libraries-for-java-folder)/mediaservices/resource-manager/v2015_10_01
regenerate-manager: true
generate-interface: true
```

### Tag: package-2018-03-preview and java

These settings apply only when `--tag=package-2018-03-preview --java` is specified on the command line.
Please also specify the `--azure-libraries-for-java-folder=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2018-03-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.mediaservices.v2018_03_30_preview
  output-folder: $(azure-libraries-for-java-folder)/mediaservices/resource-manager/v2018_03_30_preview
regenerate-manager: true
generate-interface: true
```

### Tag: package-2018-06-preview and java

These settings apply only when `--tag=package-2018-06-preview --java` is specified on the command line.
Please also specify the `--azure-libraries-for-java-folder=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2018-06-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.mediaservices.v2018_06_01_preview
  output-folder: $(azure-libraries-for-java-folder)/mediaservices/resource-manager/v2018_06_01_preview
regenerate-manager: true
generate-interface: true
```

### Tag: package-2018-07 and java

These settings apply only when `--tag=package-2018-07 --java` is specified on the command line.
Please also specify the `--azure-libraries-for-java-folder=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2018-07' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.mediaservices.v2018_07_01
  output-folder: $(azure-libraries-for-java-folder)/mediaservices/resource-manager/v2018_07_01
regenerate-manager: true
generate-interface: true
```
